mocks

package
v0.0.0-...-70fc12f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2020 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCache

type MockCache struct {
	// contains filtered or unexported fields
}

MockCache is a mock of Cache interface

func NewMockCache

func NewMockCache(ctrl *gomock.Controller) *MockCache

NewMockCache creates a new mock instance

func (*MockCache) DelOneContact

func (m *MockCache) DelOneContact(value string) error

DelOneContact mocks base method

func (*MockCache) EXPECT

func (m *MockCache) EXPECT() *MockCacheMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockCache) GetEmailByContactID

func (m *MockCache) GetEmailByContactID(key string) (string, error)

GetEmailByContactID mocks base method

func (*MockCache) GetOneContact

func (m *MockCache) GetOneContact(value string) (*entities.Contact, error)

GetOneContact mocks base method

func (*MockCache) SetEmailByContactID

func (m *MockCache) SetEmailByContactID(key, value string) error

SetEmailByContactID mocks base method

func (*MockCache) SetOneContact

func (m *MockCache) SetOneContact(value string, contact *entities.Contact) error

SetOneContact mocks base method

type MockCacheMockRecorder

type MockCacheMockRecorder struct {
	// contains filtered or unexported fields
}

MockCacheMockRecorder is the mock recorder for MockCache

func (*MockCacheMockRecorder) DelOneContact

func (mr *MockCacheMockRecorder) DelOneContact(value interface{}) *gomock.Call

DelOneContact indicates an expected call of DelOneContact

func (*MockCacheMockRecorder) GetEmailByContactID

func (mr *MockCacheMockRecorder) GetEmailByContactID(key interface{}) *gomock.Call

GetEmailByContactID indicates an expected call of GetEmailByContactID

func (*MockCacheMockRecorder) GetOneContact

func (mr *MockCacheMockRecorder) GetOneContact(value interface{}) *gomock.Call

GetOneContact indicates an expected call of GetOneContact

func (*MockCacheMockRecorder) SetEmailByContactID

func (mr *MockCacheMockRecorder) SetEmailByContactID(key, value interface{}) *gomock.Call

SetEmailByContactID indicates an expected call of SetEmailByContactID

func (*MockCacheMockRecorder) SetOneContact

func (mr *MockCacheMockRecorder) SetOneContact(value, contact interface{}) *gomock.Call

SetOneContact indicates an expected call of SetOneContact

type MockConfig

type MockConfig struct {
	// contains filtered or unexported fields
}

MockConfig is a mock of Config interface

func NewMockConfig

func NewMockConfig(ctrl *gomock.Controller) *MockConfig

NewMockConfig creates a new mock instance

func (*MockConfig) EXPECT

func (m *MockConfig) EXPECT() *MockConfigMockRecorder

EXPECT returns an object that allows the caller to indicate expected use

func (*MockConfig) GetCacheConfig

func (m *MockConfig) GetCacheConfig() *config.CacheConfig

GetCacheConfig mocks base method

func (*MockConfig) GetDBConfig

func (m *MockConfig) GetDBConfig() *config.DatabaseConfig

GetDBConfig mocks base method

type MockConfigMockRecorder

type MockConfigMockRecorder struct {
	// contains filtered or unexported fields
}

MockConfigMockRecorder is the mock recorder for MockConfig

func (*MockConfigMockRecorder) GetCacheConfig

func (mr *MockConfigMockRecorder) GetCacheConfig() *gomock.Call

GetCacheConfig indicates an expected call of GetCacheConfig

func (*MockConfigMockRecorder) GetDBConfig

func (mr *MockConfigMockRecorder) GetDBConfig() *gomock.Call

GetDBConfig indicates an expected call of GetDBConfig

type MockContactService

type MockContactService struct {
	// contains filtered or unexported fields
}

MockContactService is a mock of ContactService interface

func NewMockContactService

func NewMockContactService(ctrl *gomock.Controller) *MockContactService

NewMockContactService creates a new mock instance

func (*MockContactService) AddOrUpdateContact

func (m *MockContactService) AddOrUpdateContact(contact *entities.Contact) (string, error)

AddOrUpdateContact mocks base method

func (*MockContactService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockContactService) GetOneContact

func (m *MockContactService) GetOneContact(key, value string) (*entities.Contact, error)

GetOneContact mocks base method

type MockContactServiceMockRecorder

type MockContactServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockContactServiceMockRecorder is the mock recorder for MockContactService

func (*MockContactServiceMockRecorder) AddOrUpdateContact

func (mr *MockContactServiceMockRecorder) AddOrUpdateContact(contact interface{}) *gomock.Call

AddOrUpdateContact indicates an expected call of AddOrUpdateContact

func (*MockContactServiceMockRecorder) GetOneContact

func (mr *MockContactServiceMockRecorder) GetOneContact(key, value interface{}) *gomock.Call

GetOneContact indicates an expected call of GetOneContact

type MockDBHandler

type MockDBHandler struct {
	// contains filtered or unexported fields
}

MockDBHandler is a mock of DBHandler interface

func NewMockDBHandler

func NewMockDBHandler(ctrl *gomock.Controller) *MockDBHandler

NewMockDBHandler creates a new mock instance

func (*MockDBHandler) DeleteOne

func (m *MockDBHandler) DeleteOne(db, coll, key string, value interface{}) error

DeleteOne mocks base method

func (*MockDBHandler) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockDBHandler) FindOne

func (m *MockDBHandler) FindOne(db, coll, key string, value interface{}) (bson.M, error)

FindOne mocks base method

func (*MockDBHandler) InsertOne

func (m *MockDBHandler) InsertOne(db, coll string, value interface{}) error

InsertOne mocks base method

func (*MockDBHandler) UpdateOne

func (m *MockDBHandler) UpdateOne(db, coll, key string, value, update interface{}) error

UpdateOne mocks base method

type MockDBHandlerMockRecorder

type MockDBHandlerMockRecorder struct {
	// contains filtered or unexported fields
}

MockDBHandlerMockRecorder is the mock recorder for MockDBHandler

func (*MockDBHandlerMockRecorder) DeleteOne

func (mr *MockDBHandlerMockRecorder) DeleteOne(db, coll, key, value interface{}) *gomock.Call

DeleteOne indicates an expected call of DeleteOne

func (*MockDBHandlerMockRecorder) FindOne

func (mr *MockDBHandlerMockRecorder) FindOne(db, coll, key, value interface{}) *gomock.Call

FindOne indicates an expected call of FindOne

func (*MockDBHandlerMockRecorder) InsertOne

func (mr *MockDBHandlerMockRecorder) InsertOne(db, coll, value interface{}) *gomock.Call

InsertOne indicates an expected call of InsertOne

func (*MockDBHandlerMockRecorder) UpdateOne

func (mr *MockDBHandlerMockRecorder) UpdateOne(db, coll, key, value, update interface{}) *gomock.Call

UpdateOne indicates an expected call of UpdateOne

type MockRepository

type MockRepository struct {
	// contains filtered or unexported fields
}

MockRepository is a mock of Repository interface

func NewMockRepository

func NewMockRepository(ctrl *gomock.Controller) *MockRepository

NewMockRepository creates a new mock instance

func (*MockRepository) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockRepository) GetContactIDByAPIKey

func (m *MockRepository) GetContactIDByAPIKey(apiKey string) (string, error)

GetContactIDByAPIKey mocks base method

func (*MockRepository) GetOneContact

func (m *MockRepository) GetOneContact(key, value string) (*entities.Contact, error)

GetOneContact mocks base method

func (*MockRepository) InsertOneContact

func (m *MockRepository) InsertOneContact(contact *entities.Contact) error

InsertOneContact mocks base method

func (*MockRepository) UpdateOneContact

func (m *MockRepository) UpdateOneContact(contact *entities.Contact) error

UpdateOneContact mocks base method

type MockRepositoryMockRecorder

type MockRepositoryMockRecorder struct {
	// contains filtered or unexported fields
}

MockRepositoryMockRecorder is the mock recorder for MockRepository

func (*MockRepositoryMockRecorder) GetContactIDByAPIKey

func (mr *MockRepositoryMockRecorder) GetContactIDByAPIKey(apiKey interface{}) *gomock.Call

GetContactIDByAPIKey indicates an expected call of GetContactIDByAPIKey

func (*MockRepositoryMockRecorder) GetOneContact

func (mr *MockRepositoryMockRecorder) GetOneContact(key, value interface{}) *gomock.Call

GetOneContact indicates an expected call of GetOneContact

func (*MockRepositoryMockRecorder) InsertOneContact

func (mr *MockRepositoryMockRecorder) InsertOneContact(contact interface{}) *gomock.Call

InsertOneContact indicates an expected call of InsertOneContact

func (*MockRepositoryMockRecorder) UpdateOneContact

func (mr *MockRepositoryMockRecorder) UpdateOneContact(contact interface{}) *gomock.Call

UpdateOneContact indicates an expected call of UpdateOneContact

Jump to